/*-

Trading Strategy Code

Population member: 17

Max bars back: 33

Created by: Adaptrade Builder

Created: 12/30/2014 12:17:13 PM

Scripting language: MetaTrader 4 (MQL4)

Price file: [FOREX] EURUSD.txt

Build dates: 2/12/2001 to 4/24/2008

Project file: C:\Storici\4 forex.gpstrat

-*/

#include <AdaptradeBuilderInclude.mqh>

#define STRATORDERID 15730859

// Strategy inputs

extern int NL1 = 24; // Indicator look-back length (bars), long trades

extern double XL1 = -69.3618; // CCI indicator value, long trades

extern double MMStopSzL = 0.0009200; // Value of fixed size money management stop per share/contract, long trades

extern double TargPctL = 3.029; // Value of percentage exit target per share/contract, long trades

extern int NBarExL1 = 53; // Number of bars from entry for market exit if profitable, long trades

extern int NATREnS = 33; // Indicator look-back length (bars), short trades

extern double EntFrS = 3.1048; // Multiple of ATR, short trades

extern double TrailFlrS = 0.0007500; // Trailing stop floor value per share/contract, short trades

extern double TrailPctS = 8.0000; // Trailing stop percentage, short trades

extern int NATRMMS = 18; // Indicator look-back length (bars), short trades

extern double MMFrS = 2.8974; // Multiple of ATR, short trades

extern double PSParam = 100000.00; // Position sizing parameter value

extern bool RoundPS = true; // Round-to-nearest (true/false)

extern int RoundTo = 1; // Round-to position size value

extern int MinSize = 1; // Minimum allowable position size

extern int SizeLimit = 100000; // Maximum allowable position size

// Global strategy variables

int MaxBarsBack = 33;

double PointValue = 1.000000;

int MaxSlippage = 3;

double SharesPerLot = 100000;

// Variables for exit prices

double TargPrL;

double LStop = 0;

double SStop = 0;

double NewSStop = 0;

bool STrailOn = false;

// Main strategy code

void OnTick() {

if (IsTradeAllowed() && Bars >= MaxBarsBack) {

ManageOrders(Symbol(), STRATORDERID, MaxSlippage);

if (Volume[0] <= 1) {

// Average true range

double ATREnS = iATR(NULL, 0, NATREnS, 1);

double ATRMMS = iATR(NULL, 0, NATRMMS, 1);

// Entry price

double EntPrS = Open[1] - EntFrS * ATREnS;

EntPrS = NormalizeDouble(EntPrS, Digits);

// Entry and exit conditions

double VarL1 = iCCI(NULL, 0, NL1, PRICE_TYPICAL, 1);

bool EntCondL = VarL1 >= XL1;

bool EntCondS = true;

// Position sizing calculations

double NShares = PSParam;

if (RoundPS && RoundTo > 0)

NShares = MathFloor(NShares/RoundTo) * RoundTo;

NShares = MathMax(NShares, MinSize);

NShares = MathMin(NShares, SizeLimit);

double Lots = NShares/SharesPerLot;

// Prepare to place trading orders

int MarketPosition = CurrentPosition();

double InitialStop = 0;

// Entry orders

if (MarketPosition == 0 && EntCondL) {

EnterLongMarket(Symbol(), Lots, InitialStop, MarketPosition, MaxSlippage, STRATORDERID);

}

if (MarketPosition == 0 && EntCondS) {

EnterShortStop(Symbol(), Lots, InitialStop, MarketPosition, EntPrS, MaxSlippage, STRATORDERID);

}

// Exit orders, long trades

if (MarketPosition == 1) {

if (iBarShift(NULL, 0, OpenEntryTime) - 1 == 0) {

LStop = OpenEntryPrice - MMStopSzL/PointValue;

LStop = NormalizeDouble(LStop, Digits);

}

PlaceLongStop(Symbol(), LStop, MaxSlippage);

TargPrL = (1 + TargPctL/100.0) * OpenEntryPrice;

TargPrL = NormalizeDouble(TargPrL, Digits);

PlaceLongTarget(Symbol(), TargPrL, MaxSlippage);

if ((iBarShift(NULL, 0, OpenEntryTime) - 1 >= NBarExL1 && Close[1] > OpenEntryPrice))

ExitLongMarket(MaxSlippage);

}

// Exit orders, short trades

if (MarketPosition == -1) {

if (iBarShift(NULL, 0, OpenEntryTime) - 1 == 0) {

SStop = OpenEntryPrice + MMFrS * ATRMMS;

SStop = NormalizeDouble(SStop, Digits);

STrailOn = false;

}

if (OpenEntryPrice - Close[1] > TrailFlrS/PointValue)

STrailOn = true;

if (STrailOn) {

NewSStop = OpenEntryPrice - TrailPctS * (OpenEntryPrice - Close[1])/100.0;

SStop = MathMin(SStop, NewSStop);

SStop = NormalizeDouble(SStop, Digits);

}

PlaceShortStop(Symbol(), SStop, MaxSlippage);

}

}

}

}